import { freeze } from 'immer';
import { useImmer } from './useImmer';
import { useUnmount } from './useUnmount';
export function createGlobalState(initialValue) {
    const store = {
        state: freeze(typeof initialValue === 'function' ? initialValue() : initialValue, true),
        setState(updater) {
            for (const update of store.updates) {
                update(updater);
            }
        },
        updates: new Set(),
    };
    return () => {
        const [state, setState] = useImmer(store.state);
        store.state = state;
        if (!store.updates.has(setState)) {
            store.updates.add(setState);
        }
        useUnmount(() => {
            store.updates.delete(setState);
        });
        return [state, store.setState];
    };
}
